@@ -1,6 +1,7 @@
 #include "append_list.h"
-#include "xmalloc.h"
+#include "gettext.h"
 #include "struct_OPArg.h"
+#include "xmalloc.h"
 
 #include <stdio.h>
 #include <limits.h>
@@ -36,16 +37,15 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				/* atoiは使うべきではない、らしい */
 				off_t b_tmp = strtoll(optarg, &endptr, 10);
 
-				if(b_tmp > INT_MAX)
+				if(b_tmp > 2000)
 				{
-					fprintf(stderr, "バッファサイズの上限は2000MBです\n");
+					fprintf(stderr, _("バッファサイズの上限は2000です\n"));
 					exit(EXIT_FAILURE);
 				}
 
 				if((endptr[0] != '\0') || (errno != 0) || (b_tmp < 2))
 				{
-					fprintf(stderr, "バッファの値が正しくありません。\n");
-					fprintf(stderr, "値は2以上である必要があります。\n");
+					fprintf(stderr, _("バッファサイズの下限は2です\n"));
 					exit(EXIT_FAILURE);
 				}
 
@@ -107,7 +107,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			{
 				oparg->EFFECT = EXIST;
 			}
-			fprintf(stderr, "-oオプションは無視されます\n");
+			fprintf(stderr, _("-oオプションは無視されます\n"));
 			break;
 
 		case 'r':	/* MD5SUMでチェックする */
@@ -133,7 +133,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				break;
 
 			default:
-				fprintf(stderr, "コンペアモードの指定値が正しくありません\n");
+				fprintf(stderr, _("コンペアモードの指定値が正しくありません\n"));
 				exit(EXIT_FAILURE);
 				break;
 			}
@@ -160,7 +160,7 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				break;
 
 			default:
-				fprintf(stderr, "スレッドモードの指定値が正しくありません\n");
+				fprintf(stderr, _("スレッドモードの指定値が正しくありません\n"));
 				exit(EXIT_FAILURE);
 			}
 			break;
@@ -199,13 +199,13 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 				break;
 
 			default:
-				fprintf(stderr, "上書きモードの指定値が正しくありません\n");
+				fprintf(stderr, _("上書きモードの指定値が正しくありません\n"));
 				exit(EXIT_FAILURE);
 			}
 			break;
 
 		case '?':	/* 未知のオプション */
-			fprintf(stderr, "オプションが正しくありません\n");
+			fprintf(stderr, _("オプションが正しくありません\n"));
 			exit(EXIT_FAILURE);
 			break;
 		}
@@ -213,12 +213,12 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 
 	if(optind == (argc - 1))
 	{
-		fprintf(stderr, "引数が足りません\n");
+		fprintf(stderr, _("引数が足りません\n"));
 		exit(EXIT_FAILURE);
 	}
 	else if((oparg->EFFECT == EXIST) && (optind == argc))
 	{
-		fprintf(stderr, "引数が正しくありません\n");
+		fprintf(stderr, _("引数が正しくありません\n"));
 		exit(EXIT_FAILURE);
 	}
 
@@ -242,19 +242,22 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 
 	{
 		long psize = sysconf(_SC_PAGESIZE);
-		int size = oparg->buffer_size;
+		/* 読み書き用のバッファは2つ確保するので、サイズを半分にしておく */
+		int size = oparg->buffer_size / 2;
 		VList *b_size_list = NULL;
+		int *i;
 
 		for(;;)
 		{
 			if((size % psize) == 0)
 			{
-				int *i = xmalloc(sizeof(int));
+				i = xmalloc(sizeof(int));
 				*i = size;
 				b_size_list = append_list(i, b_size_list);
 			}
 
-			if(size <= 524288)
+			/* バッファのサイズの下限は1MB×2 */
+			if(size <= 1024 * 1024)
 			{
 				break;
 			}
