@@ -4,6 +4,7 @@
 #define _GNU_SOURCE
 
 #include "ch_time_and_mod_global.h"
+#include "gettext.h"
 #include "print_error.h"
 #include "struct_CPInfo.h"
 
@@ -23,7 +24,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 	if(fchmod(*idst, stat_buf->st_mode) == -1)
 	{
 		print_error("chmod", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
+		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 	}
 
 	/* 管理者権限がある場合のみchownする */
@@ -33,7 +34,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 		if(fchown(*idst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 		{
 			print_error("chown", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 		}
 	}
 
@@ -49,7 +50,7 @@ static inline void ch_time_and_mod(const int *idst, const struct stat *stat_buf,
 	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
 		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
+		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 	}
 }
 
