@@ -4,6 +4,7 @@
 #define _GNU_SOURCE
 
 #include "ch_time_and_mod_global.h"
+#include "gettext.h"
 #include "print_error.h"
 #include "struct_CPInfo.h"
 
@@ -26,7 +27,7 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 		if(lchown(cpinfo->dst, stat_buf->st_uid, stat_buf->st_gid) == -1)
 		{
 			print_error("lchown", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 		}
 	}
 
@@ -42,7 +43,7 @@ static inline void ch_time_and_mod_link(const struct stat *stat_buf, const CPInf
 	if(utimensat(AT_FDCWD, cpinfo->dst, time_s, AT_SYMLINK_NOFOLLOW) == -1)
 	{
 		print_error("utimensat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
+		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 	}
 }
 
