@@ -4,6 +4,7 @@
 #include "ch_time_and_mod_dir.h"
 #include "compare_verify_one.h"
 #include "create_symboliclink.h"
+#include "gettext.h"
 #include "print_error.h"
 #include "read_write.h"
 #include "remove_source_rmdir.h"
@@ -22,9 +23,10 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <glib.h>
 #include <linux/limits.h>
 
+#include <glib.h>
+
 /* 関数プロトタイプ */
 RData * check_target(const OPArg *, const VList *drive_list, const SDir *);
 static inline VList * copy_arg_link(const OPArg *, const SDir *, CPInfo *, CPDD *, VList *file_list);
@@ -53,7 +55,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 
 	if(g_file_test(oparg->argv[loop_dst], G_FILE_TEST_IS_SYMLINK) == TRUE)
 	{
-		fprintf(stderr, "コピー先がシンボリックリンクです\n");
+		fprintf(stderr, _("コピー先がシンボリックリンクです\n"));
 		exit(EXIT_FAILURE);
 	}
 
@@ -132,7 +134,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					if((errno != EEXIST) && (errno != 0))
 					{
 						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
+						fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -175,7 +177,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		if(errno != 0)
 		{
 			print_error("realpath", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
+			fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
 			exit(EXIT_FAILURE);
 		}
 
@@ -184,7 +186,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 	else
 	{
 		print_error("realpath", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
+		fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
 		exit(EXIT_FAILURE);
 	}
 
@@ -200,7 +202,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 		/* strcmpは等しければ0を返す */
 		if(strcmp(oparg->argv[loop], "..") == 0)
 		{
-			fprintf(stderr, "skip : ..\n");
+			fprintf(stderr, _("skip : ..\n"));
 			continue;
 		}
 		else if(strcmp(oparg->argv[loop], ".") == 0)
@@ -228,7 +230,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 			if(errno != 0)
 			{
 				print_error("realpath", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "error : %s\n", oparg->argv[loop]);
+				fprintf(stderr, _("error : %s\n"), oparg->argv[loop]);
 				continue;
 			}
 		}
@@ -258,7 +260,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				case SINGULAR:
 					if(is_link == true)
 					{
-						fprintf(stderr, "リンク (%s) に対するコピー先が不正 (ファイル) です\n", tmp_src);
+						fprintf(stderr, _("リンク (%s) に対するコピー先が不正 (ファイル) です\n"), tmp_src);
 						exit(EXIT_FAILURE);
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_REGULAR) == TRUE)
@@ -267,18 +269,18 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					}
 					else if(g_file_test(tmp_src, G_FILE_TEST_IS_DIR) == TRUE)
 					{
-						fprintf(stderr, "フォルダ (%s) に対するコピー先が不正 (ファイル) です\n", tmp_src);
+						fprintf(stderr, _("フォルダ (%s) に対するコピー先が不正 (ファイル) です\n"), tmp_src);
 						exit(EXIT_FAILURE);
 					}
 					else
 					{
-						fprintf(stderr, "コピー先が不正 (ファイル) です\n");
+						fprintf(stderr, _("コピー先が不正 (ファイル) です\n"));
 						exit(EXIT_FAILURE);
 					}
 					break;
 
 				default:
-					fprintf(stderr, "複数のコピー元に対するコピー先が不正 (ファイル) です\n");
+					fprintf(stderr, _("複数のコピー元に対するコピー先が不正 (ファイル) です\n"));
 					exit(EXIT_FAILURE);
 					break;
 				}
@@ -301,12 +303,12 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 				}
 				else
 				{
-					fprintf(stderr, "skip : %s\n", tmp_src);
+					fprintf(stderr, _("skip : %s\n"), tmp_src);
 				}
 			}
 			else
 			{
-				fprintf(stderr, "コピー先が不正です\n");
+				fprintf(stderr, _("コピー先が不正です\n"));
 				exit(EXIT_FAILURE);
 			}
 			break;
@@ -320,7 +322,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 					if((errno != EEXIST) && (errno != 0))
 					{
 						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "error : %s\n", oparg->argv[loop_dst]);
+						fprintf(stderr, _("error : %s\n"), oparg->argv[loop_dst]);
 						exit(EXIT_FAILURE);
 					}
 				}
@@ -352,7 +354,7 @@ RData * check_target(const OPArg *oparg, const VList *drive_list, const SDir *sd
 			}
 			else
 			{
-				fprintf(stderr, "skip : %s\n", tmp_src);
+				fprintf(stderr, _("skip : %s\n"), tmp_src);
 			}
 			break;
 		}
@@ -399,11 +401,11 @@ static inline VList * copy_arg_dir(const char *tmp_src, const char *tmp_dst, con
 	{
 		if(is_src_current == true)
 		{
-			fprintf(stderr, "skip : .\n");
+			fprintf(stderr, _("skip : .\n"));
 		}
 		else
 		{
-			fprintf(stderr, "skip : %s\n", cpinfo->src);
+			fprintf(stderr, _("skip : %s\n"), cpinfo->src);
 		}
 
 		if(cpinfo->src != NULL) free(cpinfo->src);
@@ -512,23 +514,23 @@ INPUT:
 			switch(iowt)
 			{
 			case INFO:
-				printf("overwrite? : %s\n", cpinfo->dst);
-				printf("y: Yes,  a: Yes (All),");
+				printf(_("overwrite? : %s\n"), cpinfo->dst);
+				printf(_("y: Yes,  a: Yes (All),"));
 
 				if(type == 'd')
 				{
-					puts("  d: Yes (Only this folder),");
+					puts(_("  d: Yes (Only this folder),"));
 				}
 				else
 				{
 					puts("");
 				}
 
-				printf("n:  No,  z:  No (All),");
+				printf(_("n:  No,  z:  No (All),"));
 
 				if(type == 'd')
 				{
-					puts("  o:  No (Only this folder),");
+					puts(_("  o:  No (Only this folder),"));
 				}
 				else
 				{
@@ -738,14 +740,14 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 		if((errno != EEXIST) && (errno != 0))
 		{
 			print_error("mkdir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 		}
 	}
 	else
 	{
 		if(oparg->V == VERBOS)
 		{
-			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
+			printf(_("%s -> %s\n"), cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
@@ -762,7 +764,7 @@ static inline struct stat * make_directory(const OPArg *oparg, CPInfo *cpinfo, C
 	if(stat(cpinfo->src, stat_buf) != 0)
 	{
 		print_error("stat", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->src);
+		fprintf(stderr, _("error : %s\n"), cpinfo->src);
 		free(stat_buf);
 		stat_buf = NULL;
 	}
@@ -869,7 +871,7 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 					}
 					else
 					{
-						fprintf(stderr, "skip : %s\n", cpinfo->src);
+						fprintf(stderr, _("skip : %s\n"), cpinfo->src);
 					}
 					break;
 				}
@@ -879,13 +881,13 @@ static VList * dir_traverse(const OPArg *oparg, const SDir *sdir, VList *file_li
 		if(closedir(dp) == -1)
 		{
 			print_error("closedir", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", src_dir);
+			fprintf(stderr, _("error : %s\n"), src_dir);
 		}
 	}
 	else
 	{
 		print_error("opendir", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", src_dir);
+		fprintf(stderr, _("error : %s\n"), src_dir);
 	}
 
 	/* フォルダ削除用 */
@@ -1066,7 +1068,7 @@ static inline void clean(const char stdin_buf[], const int INPUT_LEN)
 *******************************************************************************/
 static inline void fgets_is_null(void)
 {
-	fprintf(stderr, "fgetsの戻り値がNULLです\n");
+	fprintf(stderr, _("fgetsの戻り値がNULLです\n"));
 	exit(EXIT_FAILURE);
 }
 
@@ -1103,6 +1105,20 @@ for(;;)\
 *******************************************************************************/
 static inline void set_same_or_different(const VList *drive_list, const char *src, const char *dst, const OPArg *oparg, CPInfo *cpinfo)
 {
+	switch(oparg->THREAD_MODE)
+	{
+	case DRIVE_DIFFERENT:
+		cpinfo->copy_mode = DIFFERENT;
+		return;
+
+	case DRIVE_AUTO:
+		break;
+
+	default:
+		cpinfo->copy_mode = SAME;
+		return;
+	}
+
 	/*
 	 * キャストしないと警告が出る
 	 * warning: initialization discards qualifiers from pointer target type
@@ -1182,18 +1198,4 @@ DEV_CHECK_SKIP:
 	{
 		cpinfo->copy_mode = SAME;
 	}
-
-	switch(oparg->THREAD_MODE)
-	{
-	case DRIVE_DIFFERENT:
-		cpinfo->copy_mode = DIFFERENT;
-		break;
-
-	case DRIVE_AUTO:
-		break;
-
-	default:
-		cpinfo->copy_mode = SAME;
-		break;
-	}
 }
