@@ -2,20 +2,21 @@
 #define CREATE_SYMBOLICKLINK_H
 
 #define _GNU_SOURCE
+#define UNLINK_ERR \
+	print_error("unlink", __FILE__, __LINE__, cpdd);\
+	fprintf(stderr, _("error : %s\n"), cpinfo->dst);\
+	cpinfo->dst_para = INITIAL;
 
 #include "ch_time_and_mod_link.h"
+#include "gettext.h"
 #include "struct_CPDD.h"
 #include "struct_OPArg.h"
 
 #include <stdbool.h>
 
-#include <glib.h>
 #include <linux/limits.h>
 
-#define UNLINK_ERR \
-	print_error("unlink", __FILE__, __LINE__, cpdd);\
-	fprintf(stderr, "error : %s\n", cpinfo->dst);\
-	cpinfo->dst_para = INITIAL;
+#include <glib.h>
 
 /* 関数プロトタイプ */
 static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd);
@@ -61,7 +62,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 			{
 				check = false;
 				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "error : %s\n", cpinfo->src);
+				fprintf(stderr, _("error : %s\n"), cpinfo->src);
 			}
 			else if(lstat(cpinfo->dst, &stat_dst) == -1)
 			{
@@ -73,7 +74,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				{
 					check = false;
 					print_error("lstat", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "error : %s\n", cpinfo->dst);
+					fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 				}
 			}
 			else
@@ -121,7 +122,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 				default:
 					check = false;
 					print_error("NULL", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "option error : %s\n", cpinfo->src);
+					fprintf(stderr, _("option error : %s\n"), cpinfo->src);
 					break;
 				}
 			}
@@ -129,7 +130,7 @@ static void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	}
 	else
 	{
-		printf("skip : %s\n", cpinfo->dst);
+		printf(_("skip : %s\n"), cpinfo->dst);
 		fflush(stdout);
 		check = false;
 	}
@@ -152,7 +153,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 	{
 		check = false;
 		print_error("readlink", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->src);
+		fprintf(stderr, _("error : %s\n"), cpinfo->src);
 	}
 	else
 	{
@@ -174,7 +175,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 		{
 			check = false;
 			print_error("symlink", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 		}
 		else
 		{
@@ -187,7 +188,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 
 			if(oparg->V == VERBOS)
 			{
-				printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
+				printf(_("%s -> %s\n"), cpinfo->src, cpinfo->dst);
 				fflush(stdout);
 			}
 
@@ -196,7 +197,7 @@ static _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 			if(lstat(cpinfo->src, &stat_buf) == -1)
 			{
 				print_error("lstat", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "error : %s\n", cpinfo->src);
+				fprintf(stderr, _("error : %s\n"), cpinfo->src);
 			}
 			else
 			{
