@@ -1,6 +1,7 @@
 #ifndef PRINT_ERROR_H
 #define PRINT_ERROR_H
 
+#include "gettext.h"
 #include "struct_CPDD.h"
 
 #include <stdio.h>
@@ -14,7 +15,7 @@ static void print_error(const char *func, const char *source_file, const int lin
 *******************************************************************************/
 static void print_error(const char *func, const char *source_file, const int line, CPDD *cpdd)
 {
-	printf("%s : %d行\n", source_file, line);
+	printf(_("%s : %d行\n"), source_file, line);
 
 	if(strcmp(func, "NULL") != 0)
 	{
