@@ -1,5 +1,8 @@
 #define _XOPEN_SOURCE 500
+#define INPUT_LEN 256
+#define DEFAULT_BUFFER 32 * 1024 * 1024
 
+#include "gettext.h"
 #include "struct_OPArg.h"
 #include "struct_SDir.h"
 #include "xmalloc.h"
@@ -7,11 +10,9 @@
 #include <string.h>
 #include <limits.h>
 
-#include <glib.h>
 #include <unistd.h>
 
-#define INPUT_LEN 256
-#define DEFAULT_BUFFER 32 * 1024 * 1024
+#include <glib.h>
 
 /* 関数プロトタイプ */
 OPArg * read_conf(const SDir *sdir);
@@ -46,8 +47,8 @@ OPArg * read_conf(const SDir *sdir)
 
 				if(config == NULL)
 				{
-					fprintf(stderr, "設定ファイルのオープンに失敗しました\n");
-					fprintf(stderr, "強制終了します\n");
+					fprintf(stderr, _("設定ファイルのオープンに失敗しました\n"));
+					fprintf(stderr, _("強制終了します\n"));
 					exit(EXIT_FAILURE);
 				}
 
@@ -66,14 +67,14 @@ OPArg * read_conf(const SDir *sdir)
 						{
 							if(strcmp(SNOWCP_CONF_VER, ver) != 0)
 							{
-								fprintf(stderr, "設定ファイルに互換性がありません\n");
-								fprintf(stderr, "-o オプションを使用して作成し直してください\n");
+								fprintf(stderr, _("設定ファイルに互換性がありません\n"));
+								fprintf(stderr, _("-o オプションを使用して作成し直してください\n"));
 								exit(EXIT_FAILURE);
 							}
 						}
 						else
 						{
-							fprintf(stderr, "設定ファイルが正しくありません\n");
+							fprintf(stderr, _("設定ファイルが正しくありません\n"));
 							exit(EXIT_FAILURE);
 						}
 						break;
@@ -92,7 +93,7 @@ OPArg * read_conf(const SDir *sdir)
 
 								if(b > INT_MAX)
 								{
-									fprintf(stderr, "バッファサイズの上限は2000MBです\n");
+									fprintf(stderr, _("バッファサイズの上限は2000MBです\n"));
 									exit(EXIT_FAILURE);
 								}
 
@@ -101,13 +102,13 @@ OPArg * read_conf(const SDir *sdir)
 
 								if(oparg->buffer_size < 2)
 								{
-									fprintf(stderr, "バッファサイズが2以下です\n");
+									fprintf(stderr, _("バッファサイズが2以下です\n"));
 									exit(EXIT_FAILURE);
 								}
 							}
 							else
 							{
-								fprintf(stderr, "設定ファイルが正しくありません\n");
+								fprintf(stderr, _("設定ファイルが正しくありません\n"));
 								exit(EXIT_FAILURE);
 							}
 						}
@@ -139,7 +140,7 @@ OPArg * read_conf(const SDir *sdir)
 						}
 						else
 						{
-							fprintf(stderr, "設定ファイルが正しくありません\n");
+							fprintf(stderr, _("設定ファイルが正しくありません\n"));
 							exit(EXIT_FAILURE);
 						}
 						break;
@@ -160,7 +161,7 @@ OPArg * read_conf(const SDir *sdir)
 							break;
 
 						default:
-							fprintf(stderr, "設定ファイルが正しくありません\n");
+							fprintf(stderr, _("設定ファイルが正しくありません\n"));
 							exit(EXIT_FAILURE);
 							break;
 						}
@@ -192,7 +193,7 @@ OPArg * read_conf(const SDir *sdir)
 							break;
 
 						default:
-							fprintf(stderr, "設定ファイルが正しくありません\n");
+							fprintf(stderr, _("設定ファイルが正しくありません\n"));
 							exit(EXIT_FAILURE);
 							break;
 						}
@@ -204,14 +205,14 @@ OPArg * read_conf(const SDir *sdir)
 
 			if(fchdir(sdir->current_fd) == -1)
 			{
-				fprintf(stderr, "カレントディレクトリへのリターンに失敗しました\n");
+				fprintf(stderr, _("カレントディレクトリへのリターンに失敗しました\n"));
 				exit(EXIT_FAILURE);
 			}
 		}
 		else
 		{
-			fprintf(stderr, "設定フォルダにアクセスできませんでした\n");
-			fprintf(stderr, "強制終了します\n");
+			fprintf(stderr, _("設定フォルダにアクセスできませんでした\n"));
+			fprintf(stderr, _("強制終了します\n"));
 			exit(EXIT_FAILURE);
 		}
 	}
