@@ -13,7 +13,7 @@
 			if((errno != ENOTEMPTY) && (errno != ENOENT))\
 			{\
 				print_error("rmdir", __FILE__, __LINE__, cpdd);\
-				fprintf(stderr, "error : %s\n", cpinfo->src);\
+				fprintf(stderr, _("error : %s\n"), cpinfo->src);\
 			}\
 		}\
 		else \
