@@ -1,7 +1,17 @@
+/*
+ * xgettext -k"_" --from-code UTF-8 -o snowcp.pot *.c *.h
+ * msginit --locale=ja --input=snowcp.pot
+ * sed -i 's/charset=ASCII/charset=UTF-8/g' ja.po
+ * msgfmt -o snowcp.mo ja.po
+ * sudo mkdir -p /usr/local/share/locale/ja/LC_MESSAGES
+ * sudo cp snowcp.mo /usr/local/share/locale/ja/LC_MESSAGES
+ */
+
 #include "analyze_argument.h"
 #include "check_target.h"
 #include "ch_time_and_mod_global.h"
 #include "compare_verify_two.h"
+#include "gettext.h"
 #include "get_drive_list.h"
 #include "get_settings_dir.h"
 #include "help.h"
@@ -15,6 +25,7 @@
 #include "verify_hash.h"
 #include "write_conf.h"
 
+#include <locale.h> /* setlocale() */
 #include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -29,6 +40,11 @@ int main(int argc, char **argv)
 		return EXIT_SUCCESS;
 	}
 
+	setlocale(LC_ALL, "");
+//	bindtextdomain("snowcp", ".");
+	bindtextdomain("snowcp", "/usr/local/share/locale");
+	textdomain("snowcp");
+
 	SDir *sdir = get_settings_dir();
 
 	if(argc == 2)
@@ -61,7 +77,7 @@ int main(int argc, char **argv)
 		}
 		else
 		{
-			fprintf(stderr, "引数が足りません\n");
+			fprintf(stderr, _("引数が足りません\n"));
 			return EXIT_FAILURE;
 		}
 	}
@@ -72,24 +88,24 @@ int main(int argc, char **argv)
 	set_signal();
 	ut = geteuid();
 
-	puts("コピーを開始します...");
+	puts(_("コピーを開始します..."));
 	fflush(stdout);
 
 	RData *rdata = check_target(oparg, drive_list, sdir);
 
-	puts("コピーを完了しました...");
+	puts(_("コピーを完了しました..."));
 
 	VList *file_list = rdata->file_list;
 	CPDD *cpdd = rdata->cpdd;
 
 	if((file_list != NULL) && (oparg->CHECK_MODE == AFTER) && (cpdd->mk_file_count > 0))
 	{
-		puts("ハッシュ値のチェックを開始します...");
+		puts(_("ハッシュ値のチェックを開始します..."));
 		fflush(stdout);
 
 		compare_verify_two(oparg, file_list, sdir, cpdd);
 
-		puts("ハッシュ値のチェックを完了しました...");
+		puts(_("ハッシュ値のチェックを完了しました..."));
 		fflush(stdout);
 	}
 
@@ -97,11 +113,11 @@ int main(int argc, char **argv)
 
 	if(cpdd->file_count > 0)
 	{
-		printf("File   : %lld / %lld", cpdd->mk_file_count, cpdd->file_count);
+		printf(_("File   : %lld / %lld"), cpdd->mk_file_count, cpdd->file_count);
 
 		if(cpdd->thread_mode_count > 0)
 		{
-			printf(" (Thread : %lld / %lld)\n", cpdd->thread_mode_count, cpdd->mk_file_count);
+			printf(_(" (Thread : %lld / %lld)\n"), cpdd->thread_mode_count, cpdd->mk_file_count);
 		}
 		else
 		{
@@ -109,12 +125,12 @@ int main(int argc, char **argv)
 		}
 	}
 
-	if(cpdd->link_count > 0)   { printf("Link   : %llu / %llu\n", cpdd->mk_link_count, cpdd->link_count); }
-	if(cpdd->dir_count > 0)    { printf("Dir    : %llu / %llu\n", cpdd->mk_dir_count, cpdd->dir_count); }
-	if(cpdd->total_source > 0) { printf("Source : %llu MB (%llu Bytes)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source); }
-	if(cpdd->total_read > 0)   { printf("Read   : %llu MB (%llu Bytes)\n", cpdd->total_read / (1024 * 1024), cpdd->total_read); }
-	if(cpdd->total_write > 0)  { printf("Write  : %llu MB (%llu Bytes)\n", cpdd->total_write / (1024 * 1024), cpdd->total_write); }
-	if(cpdd->total_error > 0)  { printf("Error  : %llu\n", cpdd->total_error); }
+	if(cpdd->link_count > 0)   { printf(_("Link   : %llu / %llu\n"), cpdd->mk_link_count, cpdd->link_count); }
+	if(cpdd->dir_count > 0)    { printf(_("Dir    : %llu / %llu\n"), cpdd->mk_dir_count, cpdd->dir_count); }
+	if(cpdd->total_source > 0) { printf(_("Source : %llu MB (%llu Bytes)\n"), cpdd->total_source / (1024 * 1024), cpdd->total_source); }
+	if(cpdd->total_read > 0)   { printf(_("Read   : %llu MB (%llu Bytes)\n"), cpdd->total_read / (1024 * 1024), cpdd->total_read); }
+	if(cpdd->total_write > 0)  { printf(_("Write  : %llu MB (%llu Bytes)\n"), cpdd->total_write / (1024 * 1024), cpdd->total_write); }
+	if(cpdd->total_error > 0)  { printf(_("Error  : %llu\n"), cpdd->total_error); }
 
 	/*
 	 * close()する必要があるもの
