@@ -1,5 +1,7 @@
 #define _GNU_SOURCE
+#define BUF_NUM 2
 
+#include "gettext.h"
 #include "print_error.h"
 #include "struct_CPInfo.h"
 #include "struct_OPArg.h"
@@ -18,8 +20,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#define BUF_NUM 2
-
 static void *buf[BUF_NUM];
 static int fd;
 static int buffer_size_local;
@@ -95,7 +95,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 	if((is_open == true) && (close(fd) == -1))
 	{
 		print_error("close", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "error : %s\n", cpinfo->dst);
+		fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 	}
 /*
 	free(buf[0]);
@@ -114,7 +114,7 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
 		{
 			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, "NULL", sdir, cpdd, false);
 			cpinfo->dst_para = INITIAL;
 
@@ -189,10 +189,10 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 			{
 				if(oparg->M == NOT)
 				{
-					printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+					printf(_("%s : %s\n"), cpinfo->src_md5, cpinfo->src);
 				}
 
-				printf("%s : %s\n", hex_output, cpinfo->dst);
+				printf(_("%s : %s\n"), hex_output, cpinfo->dst);
 				fflush(stdout);
 			}
 
@@ -204,18 +204,18 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 		else if(cpinfo->src_size > total)
 		{
 			is_equal = false;
-			fprintf(stderr, "read error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("read error : %s\n"), cpinfo->dst);
 		}
 		else
 		{
 			is_equal = false;
-			fprintf(stderr, "hash error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("hash error : %s\n"), cpinfo->dst);
 		}
 
 		if(is_equal == false)
 		{
 			print_error("NULL", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, hex_output, sdir, cpdd, false);
 			cpinfo->dst_para = DELETE;
 
@@ -225,12 +225,12 @@ static void o_direct(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD
 				if(errno != ENOENT)
 				{
 					print_error("unlink", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "error : %s\n", cpinfo->dst);
+					fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 				}
 			}
 			else
 			{
-				fprintf(stderr, "remove : %s\n", cpinfo->dst);
+				fprintf(stderr, _("remove : %s\n"), cpinfo->dst);
 			}
 		}
 	}
