@@ -1,5 +1,6 @@
 #define _GNU_SOURCE
 
+#include "gettext.h"
 #include "print_error.h"
 #include "replace_string.h"
 #include "struct_CPInfo.h"
@@ -98,10 +99,10 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 				{
 					if(oparg->M == NOT)
 					{
-						printf("%s : %s\n", cpinfo->src_md5, cpinfo->src);
+						printf(_("%s : %s\n"), cpinfo->src_md5, cpinfo->src);
 					}
 
-					printf("%s : %s\n", ddst, cpinfo->dst);
+					printf(_("%s : %s\n"), ddst, cpinfo->dst);
 					fflush(stdout);
 				}
 
@@ -113,7 +114,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 			else
 			{
 				print_error("NULL", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "verify error : %s\n", cpinfo->dst);
+				fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
 				write_log_hash_check(cpinfo, oparg, cpinfo->src_md5, ddst, sdir, cpdd, false);
 				cpinfo->dst_para = DELETE;
 
@@ -123,19 +124,19 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 					if(errno != ENOENT)
 					{
 						print_error("unlink", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "error : %s\n", cpinfo->dst);
+						fprintf(stderr, _("error : %s\n"), cpinfo->dst);
 					}
 				}
 				else
 				{
-					fprintf(stderr, "remove : %s\n", cpinfo->dst);
+					fprintf(stderr, _("remove : %s\n"), cpinfo->dst);
 				}
 			}
 		}
 		else
 		{
 			print_error("NULL", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "verify error : %s\n", cpinfo->dst);
+			fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
 			write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 			cpinfo->dst_para = INITIAL;
 		}
@@ -143,7 +144,7 @@ void verify_md5sum(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *c
 	else
 	{
 		print_error("NULL", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "verify error : %s\n", cpinfo->dst);
+		fprintf(stderr, _("verify error : %s\n"), cpinfo->dst);
 		write_log_hash_check(cpinfo, oparg, "NULL", "NULL", sdir, cpdd, false);
 		cpinfo->dst_para = INITIAL;
 	}
