@@ -1,6 +1,7 @@
 #ifndef WRITE_LOG_COMPARE_H
 #define WRITE_LOG_COMPARE_H
 
+#include "gettext.h"
 #include "struct_CPInfo.h"
 #include "struct_SDir.h"
 
@@ -125,7 +126,7 @@ static void write_log_hash_check(const CPInfo *cpinfo, const OPArg *oparg, const
 		if(check == false)
 		{
 			print_error("fputs", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "コンペアログの保存に失敗しました\n");
+			fprintf(stderr, _("コンペアログの保存に失敗しました\n"));
 		}
 		else
 		{
@@ -140,7 +141,7 @@ static void write_log_hash_check(const CPInfo *cpinfo, const OPArg *oparg, const
 	else
 	{
 		print_error("fopen", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "コンペアログの保存に失敗しました\n");
+		fprintf(stderr, _("コンペアログの保存に失敗しました\n"));
 	}
 }
 
